@@ -7,7 +7,7 @@ use warnings 'all';
 ###############################################################################
 # METADATA
 our $AUTHORITY = 'cpan:DOUGDUDE';
-our $VERSION   = '0.106';
+our $VERSION   = '0.107';
 
 ###############################################################################
 # MOOSE
@@ -17,7 +17,7 @@ use MooseX::StrictConstructor 0.08;
 ###############################################################################
 # MODULE IMPORTS
 use Carp qw(croak);
-use English qw(-no_match_vars);
+use Class::Load qw(load_class);
 
 ###############################################################################
 # ALL IMPORTS BEFORE THIS WILL BE ERASED
@@ -64,22 +64,8 @@ sub throw {
 	# Prefix this class to the beginning of the exception class
 	$exception_class = sprintf '%s::%s', $class, $exception_class;
 
-	if ($exception_class !~ m{\A \w+ (?: :: \w+)* \z}imsx) {
-		# The class name doesn't seem good, so toss it because we don't want
-		# to be evaulating bad code.
-		croak $class->new(
-			message => 'The provided class name seemed like a bad name',
-		);
-	}
-
-	# Attempt to load the exception class
-	## no critic qw(BuiltinFunctions::ProhibitStringyEval)
-	if (!eval "use $exception_class; 1") {
-		croak $class->new(
-			message => sprintf 'Unable to initiate the %s error class: %s',
-				$exception_class, $EVAL_ERROR
-		);
-	}
+	# Load the exception class
+	load_class($exception_class);
 
 	croak $exception_class->new(%args);
 }
@@ -98,7 +84,7 @@ Net::SAJAX::Exception - Basic exception object for Net::SAJAX
 
 =head1 VERSION
 
-This documentation refers to L<Net::SAJAX::Exception> version 0.106
+This documentation refers to version 0.107
 
 =head1 SYNOPSIS
 
@@ -110,7 +96,7 @@ This documentation refers to L<Net::SAJAX::Exception> version 0.106
 
 =head1 DESCRIPTION
 
-This is a basic exception class for the L<Net::SAJAX> library.
+This is a basic exception class for the L<Net::SAJAX library|Net::SAJAX>.
 
 =head1 ATTRIBUTES
 
@@ -153,15 +139,15 @@ class.
 
 =over
 
-=item * L<Carp>
+=item * L<Carp|Carp>
 
-=item * L<English>
+=item * L<Class::Load|Class::Load>
 
-=item * L<Moose> 0.77
+=item * L<Moose|Moose> 0.77
 
-=item * L<MooseX::StrictConstructor> 0.08
+=item * L<MooseX::StrictConstructor|MooseX::StrictConstructor> 0.08
 
-=item * L<namespace::clean> 0.04
+=item * L<namespace::clean|namespace::clean> 0.04
 
 =back
 
