@@ -7,7 +7,7 @@ use warnings 'all';
 ###############################################################################
 # METADATA
 our $AUTHORITY = 'cpan:DOUGDUDE';
-our $VERSION   = '0.106';
+our $VERSION   = '0.107';
 
 ###############################################################################
 # MOOSE
@@ -45,8 +45,7 @@ that occur when converting JavaScript objects.
 
 =head1 VERSION
 
-This documentation refers to L<Net::SAJAX::Exception::JavaScriptConversion>
-version 0.106
+This documentation refers to version 0.107
 
 =head1 SYNOPSIS
 
@@ -60,18 +59,19 @@ version 0.106
 =head1 DESCRIPTION
 
 This is an exception class for exceptions that occur during conversion of
-JavaScript objects in the L<Net::SAJAX> library.
+JavaScript objects in the L<Net::SAJAX library|Net::SAJAX>.
 
 =head1 INHERITANCE
 
-This class inherits from the base class of L<Net::SAJAX::Exception> and all
-attributes and methods in that class are also in this class.
+This class inherits from the base class of
+L<Net::SAJAX::Exception|Net::SAJAX::Exception> and all attributes and
+methods in that class are also in this class.
 
 =head1 ATTRIBUTES
 
 =head2 javascript_object
 
-B<Required>. This is a native JavaScript object from L<JE> that was unable to
+B<Required>. This is a native JavaScript object from L<JE|JE> that was unable to
 be converted to a native Perl object.
 
 =head1 METHODS
@@ -82,13 +82,13 @@ This class does not contain any methods.
 
 =over
 
-=item * L<Moose> 0.77
+=item * L<Moose|Moose> 0.77
 
-=item * L<MooseX::StrictConstructor> 0.08
+=item * L<MooseX::StrictConstructor|MooseX::StrictConstructor> 0.08
 
-=item * L<Net::SAJAX::Exception>
+=item * L<Net::SAJAX::Exception|Net::SAJAX::Exception>
 
-=item * L<namespace::clean> 0.04
+=item * L<namespace::clean|namespace::clean> 0.04
 
 =back
 
