@@ -7,7 +7,7 @@ use warnings 'all';
 ###############################################################################
 # METADATA
 our $AUTHORITY = 'cpan:DOUGDUDE';
-our $VERSION   = '0.106';
+our $VERSION   = '0.107';
 
 ###############################################################################
 # MOOSE
@@ -46,8 +46,7 @@ when an error is given by the remote server.
 
 =head1 VERSION
 
-This documentation refers to L<Net::SAJAX::Exception::RemoteError> version
-0.106
+This documentation refers to version 0.107
 
 =head1 SYNOPSIS
 
@@ -60,12 +59,13 @@ This documentation refers to L<Net::SAJAX::Exception::RemoteError> version
 =head1 DESCRIPTION
 
 This is an exception class for an error given by the remote server by the SAJAX
-protocol in the L<Net::SAJAX> library.
+protocol in the L<Net::SAJAX library|Net::SAJAX>.
 
 =head1 INHERITANCE
 
-This class inherits from the base class of L<Net::SAJAX::Exception> and all
-attributes and methods in that class are also in this class.
+This class inherits from the base class of
+L<Net::SAJAX::Exception|Net::SAJAX::Exception> and all attributes and
+methods in that class are also in this class.
 
 =head1 METHODS
 
@@ -77,13 +77,13 @@ This returns the error message prefixed with C<"Recieved error message: ">.
 
 =over
 
-=item * L<Moose> 0.77
+=item * L<Moose|Moose> 0.77
 
-=item * L<MooseX::StrictConstructor> 0.08
+=item * L<MooseX::StrictConstructor|MooseX::StrictConstructor> 0.08
 
-=item * L<Net::SAJAX::Exception>
+=item * L<Net::SAJAX::Exception|Net::SAJAX::Exception>
 
-=item * L<namespace::clean> 0.04
+=item * L<namespace::clean|namespace::clean> 0.04
 
 =back
 
